@@ -257,11 +257,16 @@ class DirectedGraphNetwork(object):
         if holes is not None:
             split_holes = []
             for hole in holes:
-                hole = hole.remove_colinear_vertices(tolerance)
-                hole_sgs = cls._intersect_segments(
-                    hole.segments, split_segments, tolerance)
-                hole_pts = [seg.p1 for seg in hole_sgs]
-                split_holes.append(boundary.__class__(hole_pts))
+                try:
+                    hole = hole.remove_colinear_vertices(tolerance)
+                    hole_sgs = cls._intersect_segments(
+                        hole.segments, split_segments, tolerance)
+                    hole_pts = [seg.p1 for seg in hole_sgs]
+                    split_holes.append(boundary.__class__(hole_pts))
+                except AssertionError:
+                    pass  # degenerate hole to ignore
+            if len(split_holes) == 0:
+                split_holes = None
 
         # make the directed graph for the boundary + holes
         dg = cls.from_shape_with_holes(split_boundary, split_holes, tolerance)
@@ -615,7 +620,7 @@ class DirectedGraphNetwork(object):
                 remaining_nodes.insert(0, remaining_nodes.pop(j))
             iter_count += 1
 
-        # if we wer not able to address all nodes, see if they are all in the same loop
+        # if we were not able to address all nodes, see if they are all in the same loop
         if len(remaining_nodes) >= 3:
             current_node = remaining_nodes.pop(0)
             current_node_adj = [node.key for node in node.adj_lst]
